Learn R Programming

drugDemand (version 0.1.3)

f_cum_dose: Cumulative Dose

Description

Obtains the cumulative dose given treatment duration and dosing schedule.

Usage

f_cum_dose(x, w, d, N)

Value

The cumulative dose to dispense for the drug over a specified treatment duration.

Arguments

x

Treatment duration.

w

Number of days per treatment cycle.

d

Dose per treatment cycle.

N

Maximum number of treatment cycles.

Author

Kaifeng Lu, kaifenglu@gmail.com

Examples

Run this code

f_cum_dose(c(28, 70), 21, 2, 10000)

Run the code above in your browser using DataLab