powered by
Obtains the cumulative dose given treatment duration and dosing schedule.
f_cum_dose(x, w, d, N)
The cumulative dose to dispense for the drug over a specified treatment duration.
Treatment duration.
Number of days per treatment cycle.
Dose per treatment cycle.
Maximum number of treatment cycles.
Kaifeng Lu, kaifenglu@gmail.com
f_cum_dose(c(28, 70), 21, 2, 10000)
Run the code above in your browser using DataLab