- vf
A data frame for subject-level drug dispensing data,
including the following variables:
drug, drug_name, kit, kit_name,
usubjid, treatment, treatment_description,
arrivalTime, time, event, dropout,
day, dose, cum_dose, and row_id.
- dosing_schedule_df
A data frame providing dosing schedule
information. It contains the following variables:
kit, target_days, target_dose, and
max_cycles.
- model_k0
The model for the number of skipped
visits between randomization and the first drug dispensing visit.
Options include "constant", "poisson", "zero-inflated poisson",
and "negative binomial".
- model_t0
The model for the gap time between randomization
and the first drug dispensing visit when there is no visit skipping.
Options include "constant", "exponential", "weibull",
"log-logistic", and "log-normal".
- model_t1
The model for the gap time between randomization
and the first drug dispensing visit when there is visit skipping.
Options include "least squares", and "least absolute deviations".
- model_ki
The model for the number of skipped
visits between two consecutive drug dispensing visits.
Options include "constant", "poisson", "zero-inflated poisson",
and "negative binomial".
- model_ti
The model for the gap time between two consecutive
drug dispensing visits. Options include "least squares"
and "least absolute deviations".
- model_di
The model for the dispensed doses at drug
dispensing visits. Options include "constant",
"linear model", and "linear mixed-effects model".
- nreps
The number of simulations for drawing posterior model
parameters.
- showplot
A Boolean variable that controls whether or not to
show the model fit plot. It defaults to TRUE.